# - Clone and build CatalogueAPI Module
include(ExternalProject)

find_package(Git REQUIRED)

SET(CATALOGUEAPI_SOURCES_PATH ${CMAKE_SOURCE_DIR}/3rdparty/CatalogueAPI)
SET(CATALOGUEAPI_BUILD_PATH ${CATALOGUEAPI_SOURCES_PATH}/build)
SET(CATALOGUEAPI_QXORM_LIB_PATH ${CATALOGUEAPI_BUILD_PATH}/subprojects/QxOrm)
SET(CatalogueAPI_build_type plain)

string(TOLOWER ${CMAKE_BUILD_TYPE} CMAKE_BUILD_TYPE_TOLOWER)

ExternalProject_Add(
    CatalogueAPI

    GIT_REPOSITORY https://perrinel@hephaistos.lpp.polytechnique.fr/rhodecode/GIT_REPOSITORIES/LPP/Users/mperrinel/CatalogueAPI
    GIT_TAG develop

    UPDATE_COMMAND git pull
    PATCH_COMMAND ""

    SOURCE_DIR "${CATALOGUEAPI_SOURCES_PATH}"
    CONFIGURE_COMMAND meson --prefix=${CATALOGUEAPI_SOURCES_PATH} --buildtype=${CMAKE_BUILD_TYPE_TOLOWER} "${CATALOGUEAPI_SOURCES_PATH}" "${CATALOGUEAPI_BUILD_PATH}"

    BUILD_COMMAND ninja -C "${CATALOGUEAPI_BUILD_PATH}"
    INSTALL_COMMAND ninja -C "${CATALOGUEAPI_BUILD_PATH}" install
    TEST_COMMAND ninja -C "${CATALOGUEAPI_BUILD_PATH}" test
    LOG_DOWNLOAD 1
    LOG_UPDATE 1
)

ExternalProject_Add_Step(
  CatalogueAPI CopyToBin
  COMMAND ${CMAKE_COMMAND} -E copy_directory ${CATALOGUEAPI_SOURCES_PATH}/lib64 ${CATALOGUEAPI_SOURCES_PATH}/lib
  COMMAND ${CMAKE_COMMAND} -E copy_directory ${CATALOGUEAPI_QXORM_LIB_PATH} ${CATALOGUEAPI_SOURCES_PATH}/lib
  DEPENDEES install
)


set(CATALOGUEAPI_INCLUDE ${CATALOGUEAPI_SOURCES_PATH}/src)
set(CATALOGUEAPI_LIBRARIES  ${CATALOGUEAPI_SOURCES_PATH}/lib/${CMAKE_SHARED_LIBRARY_PREFIX}CatalogueAPI${CMAKE_SHARED_LIBRARY_SUFFIX})
list(APPEND CATALOGUEAPI_LIBRARIES ${CATALOGUEAPI_SOURCES_PATH}/lib/${CMAKE_SHARED_LIBRARY_PREFIX}QxOrm${CMAKE_SHARED_LIBRARY_SUFFIX})

#message("CMAKE_SHARED_LIBRARY_PREFIX: ${CMAKE_SHARED_LIBRARY_PREFIX}")
#message("CMAKE_SHARED_LIBRARY_SUFFIX: ${CMAKE_SHARED_LIBRARY_SUFFIX}")
#message("CATALOGUEAPI_INCLUDE: ${CATALOGUEAPI_INCLUDE}")
#message("CATALOGUEAPI_LIBRARIES: ${CATALOGUEAPI_LIBRARIES}")

mark_as_advanced(CATALOGUEAPI_INCLUDE)
mark_as_advanced(CATALOGUEAPI_LIBRARIES)
